@@ -6,7 +6,7 @@ from starkware.starknet.services.api.contract_definition import (
 )
 
 
-def patch_contract_hash_computation() -> None:
+def disable_contract_hash_computation() -> None:
     def patch(
         contract_definition: ContractDefinition,
         hash_func: Callable[[int, int], int],
